Functions
- array_
length - Get the length (cardinality) of an array expression
- array_
negative_ index_ to_ positive - convert_
nested_ transforms - Converts nested transform calls to a different function.
- direct_
binary_ operator_ translation - Default translation for a binary operator.
- direct_
function_ translation - Default translation for a function call. It just calls a SQL function with the same name.
- direct_
unary_ operator_ translation - Default translation for a unary operator.
- function_
translation_ respecting_ ignore_ nulls - hamelin_
array_ index_ to_ sql_ with_ negatives - Convert a zero-based Hamelin index to one-based SQL index, handling negative indices For array slicing operations where negative indices need special handling
- hamelin_
string_ index_ to_ sql_ with_ negatives - Convert a zero-based Hamelin string index to one-based SQL index, handling negative indices For string operations like substr where negative indices need special handling
- interval_
range_ to_ timestamp_ range - Converts a timestamp range from an interval range by converting each interval to a timestamp by adding it to now().
- interval_
to_ range - Converts an interval expression to a timestamp range from now() + interval to now().
- interval_
to_ timestamp - Converts an interval expression to a timestamp by calculating now() + interval.
- string_
length - Get the length of a string expression
- string_
negative_ index_ to_ positive - timestamp_
to_ range - Converts a timestamp expression to a timestamp range from timestamp to now().
- to_
sql_ concat - Default translation for a binary operator that calls SQL’s concatenation operator.
- within_
range - A helper that implements WITHIN (range) and also (exp) IN (range) where range is a literal
- within_
range_ expr - A helper that implements WITHIN (range) and also (exp) IN (range) where range is an expression
- wrap_
timestamp